<?php
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**
 * We are blissfully unaware of anything.
 */
define('WP_SETUP_CONFIG', true);

/**
 * Disable error reporting
 *
 * Set this to error_reporting( E_ALL ) or error_reporting( E_ALL | E_STRICT ) for debugging
 */
error_reporting(0);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
define('WP_DEBUG', false);
/**#@-*/

require_once(ABSPATH . WPINC . '/load.php');
require_once(ABSPATH . WPINC . '/compat.php');
require_once(ABSPATH . WPINC . '/functions.php');
require_once(ABSPATH . WPINC . '/class-wp-error.php');
require_once(ABSPATH . WPINC . '/version.php');

if (!file_exists(ABSPATH . 'wp-config-sample.php'))
	wp_die('Potrebna nam je a wp-config-sample.php datoteka za instalaciju. Molimo vas da je ponovo prenesete iz va&#353;e WordPress instalaciju.');

$configFile = file(ABSPATH . 'wp-config-sample.php');

// Check if wp-config.php has been created
if (file_exists(ABSPATH . 'wp-config.php'))
	wp_die("<p>Datoteka 'wp-config.php' ve&#263; postoji. Ako trebate promijeniti bilo kakve konfiguracijske stavke u ovoj datoteci, prvo je obri&#353;ite. Sada mo&#382;ete probati pokrenuti <a href='install.php'>instalaciju</a>.</p>");

// Check if wp-config.php exists above the root directory but is not part of another install
if (file_exists(ABSPATH . '../wp-config.php') && ! file_exists(ABSPATH . '../wp-settings.php'))
	wp_die("<p>Datoteka 'wp-config.php' ve&#263; postoji i nalazi se jedan nivo iznad va&#353;e WordPress instalacije. Ako trebate promijeniti bilo kakve konfiguracijske stavke u ovoj datoteci, prvo je obri&#353;ite. Sada mo&#382;ete probati pokrenuti <a href='install.php'>instalaciju</a>.</p>");

if ( version_compare( $required_php_version, phpversion(), '>' ) )
	wp_die( sprintf( /*WP_I18N_OLD_PHP*/'Va&#353; server koristi PHP u ina&#269;ici %1$s ali WordPress tra&#382;i najmanje ina&#269;icu %2$s.'/*/WP_I18N_OLD_PHP*/, phpversion(), $required_php_version ) );

if ( !extension_loaded('mysql') && !file_exists(ABSPATH . 'wp-content/db.php') )
	wp_die( /*WP_I18N_OLD_MYSQL*/'Va&#353;oj PHP instalaciji izgleda nedostaje ekstenzija MySQL, neophodna za WordPress.'/*/WP_I18N_OLD_MYSQL*/ );

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>WordPress &rsaquo; Setup Konfiguracijska Datoteka</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />

</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>Dobro do&#353;li u WordPress. Prije nego &#353;to po&#269;nemo, potrebne su nam neke informacije o bazi podataka. Morat &#263;ete znati sljede&#263;e stavke prije nego &#353;to mo&#382;emo nastaviti.</p>
<ol>
	<li>Ime baze podataka</li>
	<li>Korisni&#269;ko ime baze podataka</li>
	<li>Lozinka baze podataka</li>
	<li>Host baze podataka</li>
	<li>Prefiks tablice (ukoliko &#382;elite imati vi&#353;e WordPress instalacija unutar jedne baze podataka) </li>
</ol>
<p><strong>Ako iz bilo kojeg razlog automatsko kreiranje datoteke ne uspije, ne zabrinjavajte se. Ovdje se samo upisuju informacije o bazi podaka u konfiguracijsku datoteku. Tako&#273;er mo&#382;ete jednostavno otvoriti <code>wp-config-sample.php</code> u nekom ure&#273;iva&#269;u za tekst, popuniti informacije i snimiti datoteku kao <code>wp-config.php</code>. </strong></p>
<p>U svakom slu&#269;aju, ove informacije vam je dostavio va&#353; web host. Ako nemate ove informacije, morat &#263;ete ga kontaktirati prije nego nastavite. Ako ste spremni&hellip;</p>

<p class="step"><a href="setup-config.php?step=1<?php if ( isset( $_GET['noapi'] ) ) echo '&amp;noapi'; ?>" class="button">Zapo&#269;nimo!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>Ispod trebate upisati detalje o povezivanju sa bazom podataka. Ako niste sigurni &#353;to upisati, kontaktirajte va&#353;eg web hosta. </p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">Ime Baze Podataka</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>Ime baze u kojoj &#263;e se nalaziti WordPressovi podaci. </td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">Korisni&#269;ko Ime</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="korisni&#269;ko ime" /></td>
			<td>Va&#353;e MySQL korisni&#269;ko ime</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">Lozinka</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="lozinka" /></td>
			<td>...i MySQL lozinka.</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">Host Baze Podataka</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td>Ovu ste informaciju trebali dobiti od va&#353;eg web hosta, ako <code>localhost</code> ne funkcionira.</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">Prefiks Tablice</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>Ako &#382;elite imati vi&#353;e instalacija WordPressa u jednoj bazi podataka, promijenite ovu vrijednost.</td>
		</tr>
	</table>
	<?php if ( isset( $_GET['noapi'] ) ) { ?><input name="noapi" type="hidden" value="true" /><?php } ?>
	<p class="step"><input name="submit" type="submit" value="Snimi" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if ( empty($prefix) )
		$prefix = 'wp_';

	// Validate $prefix: it can only contain letters, numbers and underscores
	if ( preg_match( '|[^a-z0-9_]|i', $prefix ) )
		wp_die( /*WP_I18N_BAD_PREFIX*/'<strong>GRE&#352;KA</strong>: "Prefiks Tablice" mo&#382;e sadr&#382;avati samo brojeve, slova i doljnju crticu.'/*/WP_I18N_BAD_PREFIX*/ );

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( ! empty( $wpdb->error ) ) {
		$back = '<p class="step"><a href="setup-config.php?step=1" onclick="javascript:history.go(-1);return false;" class="button">Poku&#353;ajte Ponovno</a></p>';
		wp_die( $wpdb->error->get_error_message() . $back );
	}

	// Fetch or generate keys and salts.
	$no_api = isset( $_POST['noapi'] );
	require_once( ABSPATH . WPINC . '/plugin.php' );
	require_once( ABSPATH . WPINC . '/l10n.php' );
	require_once( ABSPATH . WPINC . '/pomo/translations.php' );
	if ( ! $no_api ) {
		require_once( ABSPATH . WPINC . '/class-http.php' );
		require_once( ABSPATH . WPINC . '/http.php' );
		wp_fix_server_vars();
		/**#@+
		 * @ignore
		 */
		function get_bloginfo() {
			return ( ( is_ssl() ? 'https://' : 'http://' ) . $_SERVER['HTTP_HOST'] . str_replace( $_SERVER['PHP_SELF'], '/wp-admin/setup-config.php', '' ) );
		}
		/**#@-*/
		$secret_keys = wp_remote_get( 'https://api.wordpress.org/secret-key/1.1/salt/' );
	}

	if ( $no_api || is_wp_error( $secret_keys ) ) {
		$secret_keys = array();
		require_once( ABSPATH . WPINC . '/pluggable.php' );
		for ( $i = 0; $i < 8; $i++ ) {
			$secret_keys[] = wp_generate_password( 64, true, true );
		}
	} else {
		$secret_keys = explode( "\n", wp_remote_retrieve_body( $secret_keys ) );
		foreach ( $secret_keys as $k => $v ) {
			$secret_keys[$k] = substr( $v, 28, 64 );
		}
	}
	$key = 0;

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				$configFile[$line_num] = str_replace("ovdje_upisite_ime_baze", $dbname, $line);
				break;
			case "define('DB_USER'":
				$configFile[$line_num] = str_replace("'ovdje_upisite_korisnicko_ime'", "'$uname'", $line);
				break;
			case "define('DB_PASSW":
				$configFile[$line_num] = str_replace("'ovdje_upisite_lozinku'", "'$passwrd'", $line);
				break;
			case "define('DB_HOST'":
				$configFile[$line_num] = str_replace("localhost", $dbhost, $line);
				break;
			case '$table_prefix  =':
				$configFile[$line_num] = str_replace('wp_', $prefix, $line);
				break;
			case "define('AUTH_KEY":
			case "define('SECURE_A":
			case "define('LOGGED_I":
			case "define('NONCE_KE":
			case "define('AUTH_SAL":
			case "define('SECURE_A":
			case "define('LOGGED_I":
			case "define('NONCE_SA":
				$configFile[$line_num] = str_replace('ovdje unesite svoju jedinstvenu frazu', $secret_keys[$key++], $line );
				break;
		}
	}
	if ( ! is_writable(ABSPATH) ) :
		display_header();
?>
<p>&#381;alim, ali ne mogu zapisivati u <code>wp-config.php</code> datoteku.</p>
<p>Mo&#382;ete kreirati <code>wp-config.php</code> ru&#269;no i kopirati navedeni tekst u nju.</p>
<textarea cols="98" rows="15" class="code"><?php
		foreach( $configFile as $line ) {
			echo htmlentities($line, ENT_COMPAT, 'UTF-8');
		}
?></textarea>
<p>Nakon &#353;to ste to napravili, kliknite "Po&#269;etak instalacije."</p>
<p class="step"><a href="install.php" class="button">Po&#269;etak instalacije</a></p>
<?php
	else :
		$handle = fopen(ABSPATH . 'wp-config.php', 'w');
		foreach( $configFile as $line ) {
			fwrite($handle, $line);
		}
		fclose($handle);
		chmod(ABSPATH . 'wp-config.php', 0666);
		display_header();
?>
<p>Ide&#353; Miki! Zavr&#353;ili ste sa ovim dijelom instalacije. WordPress sada mo&#382;e komunicirati sa va&#353;om bazom podataka. Ako ste spremni, vrijeme je za&hellip;</p>

<p class="step"><a href="install.php" class="button">Po&#269;etak instalacije</a></p>
<?php
	endif;
	break;
}
?>
</body>
</html>
